@@ -26,9 +26,11 @@ class Server(StrEnum):
     HI_KUMO_OCEANIA = "hi_kumo_oceania"
     NEXITY = "nexity"
     REXEL = "rexel"
+    SAUTER_COZYTOUCH = "sauter_cozytouch"
     SIMU_LIVEIN2 = "simu_livein2"
     SOMFY_DEVELOPER_MODE = "somfy_developer_mode"
     SOMFY_EUROPE = "somfy_europe"
     SOMFY_AMERICA = "somfy_america"
     SOMFY_OCEANIA = "somfy_oceania"
+    THERMOR_COZYTOUCH = "thermor_cozytouch"
     UBIWIZZ = "ubiwizz"
